#    This file is part of MDANSE_GUI.
#
#    MDANSE_GUI is free software: you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation, either version 3 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program.  If not, see <https://www.gnu.org/licenses/>.
#
from collections import defaultdict
from typing import TYPE_CHECKING

import numpy as np
from qtpy.QtCore import Signal, Slot
from qtpy.QtWidgets import QTextBrowser

if TYPE_CHECKING:
    from MDANSE.Chemistry.ChemicalSystem import ChemicalSystem


class PlotDataInfo(QTextBrowser):
    error = Signal(str)

    def __init__(self, *args, **kwargs):
        self._header = kwargs.pop("header", "")
        self._footer = kwargs.pop("footer", "")
        super().__init__(*args, **kwargs)
        self.setOpenExternalLinks(True)

    @Slot(object)
    def update_panel(self, input_text):
        try:
            text = "\n".join([f"{key}: {item}" for key, item in input_text.items()])
        except Exception:
            text = str(input_text)
        filtered = self.filter(text)
        self.setHtml(filtered)

    def summarise_chemical_system(self, cs: "ChemicalSystem"):
        text = "\n ==== Chemical System summary ==== \n"
        atoms, counts = np.unique(cs.atom_list, return_counts=True)
        for ind in range(len(atoms)):
            text += f"Element: {atoms[ind]}; Count: {counts[ind]}\n"
        for molname, mollist in cs._clusters.items():
            text += f"Molecule: {molname}; Count: {len(mollist)}"
        text += " ===== \n"
        return text

    def filter(self, some_text: str, line_break="<br />"):
        new_text = ""
        if self._header:
            new_text += self._header + line_break
        if some_text is not None:
            new_text += line_break.join([x.strip() for x in some_text.split("\n")])
        if self._footer:
            new_text += line_break + self._footer
        return new_text
